# emacs-mode: -*- python-*-
import config
import uiconfig
import baseui
import ui
import runtime
import utils
import status
from setting import setting
class StorageFullError(Exception):
    __module__ = __name__

class NoModifyError(Exception):
    __module__ = __name__

class Stage:
    __module__ = __name__
    name = ''
    agenda_forbidden = False

    def set_name(self, name):
        self.name = name



    def get_name(self):
        return self.name



    def destroy(self):
        self.ui.destroy()
        self.ui = None



    def is_active(self):
        return (self == runtime.manager.stage)



    def show(self):
        self.ui.show()



    def hide(self):
        self.ui.hide()



    def handle_key(self, key):
        return False



    def handle_net_ev(self, *ev):
        return False



    def oninit(self):
        pass


class TempStage(Stage):
    __module__ = __name__
    agenda_forbidden = True

    def __init__(self, cb):

        def run_cb():
            self.cb_tag = None
            cb()
            return False


        self.cb_tag = runtime.evas.idle_add(cb)
        self.ui = baseui.BaseUI('', '', '')



    def destroy(self):
        Stage.destroy(self)
        if self.cb_tag:
            runtime.evas.idle_remove(self.cb_tag)



class ListStage(Stage):
    __module__ = __name__

    def __init__(self, choice = None, title = None, icon = None, onlyview = False, trans = False, arrow = False):
        self.trans = trans
        if (title == None):
            title = self.title
        if (choice == None):
            choice = self.choice
        if (icon == None):
            try:
                icon = self.icon
            except:
                pass
        self.choice_updated = False
        self.arrow = arrow
        self.ui = baseui.ListUI(_('OK'), _('BACK'), title, icon=icon, view=onlyview, trans=self.trans, arrow=self.arrow)
        self.ui.set_list(choice)



    def handle_key(self, key):
        if config.key_debug:
            print '[HK] ListStage:handle_key() key =',
            print key
        if (key == config.Menu1):
            if config.detail_debug:
                print '   self.ui.get_focus() =',
                print self.ui.get_focus()
            if (self.ui.get_focus() >= 0):
                self.activate(self.ui.get_focus())
            return True
        elif (key == config.Menu2):
            runtime.manager.back_stage()
            return True
        elif (key in ('Up',
         'Down')):
            return self.ui.handle_key(key)
        if config.detail_debug:
            print '   ListStage: return False'
        return False



    def show(self):
        if self.choice_updated:
            self.ui.update_lists(self.choice)
            self.choice_updated = False
        Stage.show(self)



    def change_choice(self, choice):
        self.choice_updated = True
        self.choice = choice



class ListStage2(ListStage):
    __module__ = __name__

    def __init__(self, choice = None, title = None, icon = None, x = uiconfig.list2_pos_x, onlyview = False, trans = False):
        self.trans = trans
        self.x = x
        if (title == None):
            title = self.title
        if (choice == None):
            choice = self.choice
        if (icon == None):
            try:
                icon = self.icon
            except:
                pass
        self.choice_updated = False
        self.ui = baseui.ListUI2(_('OK'), _('BACK'), title, icon=icon, x=self.x, view=onlyview, trans=self.trans)
        self.ui.set_list(choice)



    def handle_key(self, key):
        if config.key_debug:
            print '[HK] ListStage:handle_key() key =',
            print key
        if (key == config.Menu1):
            if config.detail_debug:
                print '   self.ui.get_focus() =',
                print self.ui.get_focus()
            if (self.ui.get_focus() >= 0):
                self.activate(self.ui.get_focus())
            return True
        elif (key == config.Menu2):
            runtime.manager.back_stage()
            return True
        elif (key in ('Up',
         'Down')):
            return self.ui.handle_key(key)
        if config.detail_debug:
            print '   ListStage: return False'
        return False



    def show(self):
        if self.choice_updated:
            self.ui.update_lists(self.choice)
            self.choice_updated = False
        Stage.show(self)



    def change_choice(self, choice):
        self.choice_updated = True
        self.choice = choice



class CheckListStage(Stage):
    __module__ = __name__

    def __init__(self, choice = None, title = None, icon = None):
        if (title == None):
            title = self.title
        if (choice == None):
            choice = self.choice
        if (icon == None):
            try:
                icon = self.icon
            except:
                pass
        self.ui = baseui.CheckListUI(_('SELECT'), _('BACK'), title, icon=icon)
        self.ui.set_list(choice)



    def handle_key(self, key):
        if (key == config.Menu1):
            self.ui.toggle()
            return True
        elif (key == config.Menu2):
            runtime.manager.back_stage()
            return True
        return self.ui.handle_key(key)



class GaugeStage(Stage):
    __module__ = __name__

    def __init__(self, value, title = None):
        if (title == None):
            title = self.title
        self.ui = baseui.GaugeUI(_('OK'), _('BACK'), title)
        self.ui.set_value(value)



    def handle_key(self, key):
        if (key == config.Menu1):
            self.activate(self.ui.get_value())
        elif (key == config.Menu2):
            runtime.manager.back_stage()
        elif (key in ('Up',
         'Down')):
            self.ui.handle_key(key)
        else:
            return False
        return True



class YesNoStage(Stage):
    __module__ = __name__

    def __init__(self, message, yes_cb, no_cb, title, icon):
        self.ui = baseui.YesNoUI(title, message, icon)
        self.yes_cb = yes_cb
        self.no_cb = no_cb



    def handle_key(self, key):
        if (key == config.Menu1):
            self.yes_cb()
        elif (key == config.Menu2):
            self.no_cb()
        else:
            return False
        return True



class OkNoStage(YesNoStage):
    __module__ = __name__

    def __init__(self, message, yes_cb, no_cb, title, icon):
        self.ui = baseui.OkNoUI(title, message, icon)
        self.yes_cb = yes_cb
        self.no_cb = no_cb



class EntryStage(Stage):
    __module__ = __name__

    def __init__(self, sub_label, title, left = _('OK'), right = _('BACK')):
        self.ui = baseui.EntryUI(left, right, title, sub_label)
        self.set_fixed_automata('', False)



    def show(self):
        status.editing = True
        Stage.show(self)



    def hide(self):
        status.editing = False
        Stage.hide(self)



    def destroy(self):
        status.editing = False
        Stage.destroy(self)



    def set_fixed_automata(self, name, casemode):
        self.ui.set_fixed_automata(name, casemode)



    def t9_add_word(self, word):
        self.ui.entry.t9_add_word(word)
        self.ui.update_entry_info()



    def insert_symbol(self, s):
        self.ui.insert_text(s)



    def is_valid_email(self):
        t = self.ui.get_text()
        if ((t.find('@') >= 0) and (t.find('.') >= 0)):
            return True
        return False



    def activate_menu2(self):
        runtime.manager.back_stage()



    def handle_key(self, key):
        if (key == config.Menu1):
            if self.ui.is_t9_add_word_mode():
                runtime.manager.stack_stage(T9AddWordStage(self))
            else:
                self.ui.reset_automata()
                self.activate_menu1()
            return True
        elif (key == config.Menu2):
            if self.ui.handle_key(key):
                return True
            if (self.ui.right == _('INFO T9')):
                runtime.manager.stack_stage(InfoT9Stage)
                return True
            else:
                self.activate_menu2()
                return True
        elif ((key == '*') and ((not self.ui.is_t9_editing_mode()) and (not self.ui.fixed_automata))):
            self.ui.reset_automata()
            runtime.manager.stack_stage(SymbolSelectionStage(self))
            return True
        else:
            return self.ui.handle_key(key)
        return False



class NotifyStage(Stage):
    __module__ = __name__
    agenda_forbidden = True

    def __init__(self, message, icon, cb = None, duration = 0):
        self.ui = baseui.NotifyUI(message, icon)

        def destroy():
            runtime.manager.back_stage()
            return False


        self.cb = (cb or destroy)

        def run_cb():
            self.destroy_tag = 0
            self.cb()


        duration = (duration or uiconfig.notify_duration)
        self.destroy_tag = utils.Timer(duration, run_cb)



    def handle_key(self, key):
        if (key == config.Red):
            self.destroy_tag = 0
            self.cb()
            return True
        return Stage.handle_key(self, key)



    def destroy(self):
        Stage.destroy(self)
        self.destroy_tag = 0



class SetDateStage(Stage):
    __module__ = __name__

    def __init__(self, title, date, done_cb, icon = None):
        self.ui = ui.DateEditUI(title, _('Set date:'), date, icon)
        self.done_cb = done_cb



    def handle_key(self, key):
        if (key == config.Menu1):
            if self.ui.handle_key(key):
                (year, mon, day,) = self.ui.date
                self.done_cb((year,
                 mon,
                 day))
                return True
        else:
            return self.ui.handle_key(key)



class TerminalNumberStage(Stage):
    __module__ = __name__

    def __init__(self, our_terminal):
        self.ui = ui.DigitEditUI(' ', _('TERMINAL NUMBER'), _('Number'))
        self.our_terminal = our_terminal
        if our_terminal:
            self.ui.handle_key(setting.terminal_number)
            self.ui.set_right(_('BACK'))
        elif status.callee_terminal_number:
            self.ui.handle_key(status.callee_terminal_number)
            self.ui.set_right(_('DELETE'))
        elif status.mms_editing:
            if (':' in status.mms_read_message.number[0][-1]):
                self.ui.handle_key(status.mms_read_message.number[0][-1].split(':')[-1])
                self.ui.set_right(_('DELETE'))
        else:
            self.ui.set_right(_('BACK'))



    def activate_menu1(self):
        if ((len(self.ui.get_text()) == 0) and (not self.our_terminal)):
            if status.mms_editing:
                new_number = ((status.mms_read_message.number[0][-1].split(':')[0] + ':') + self.ui.get_text())
                status.mms_read_message.number[0][-1] = new_number
                icon = uiconfig.baloon_mms_icon
            else:
                status.callee_terminal_number = self.ui.get_text()
                icon = uiconfig.baloon_message_icon
            stage = NotifyStage(_('Terminal number not set'), icon)
            runtime.manager.change_stage(stage)
        elif (len(self.ui.get_text()) >= 1):
            if self.our_terminal:
                setting.terminal_number = self.ui.get_text()
                icon = uiconfig.baloon_message_icon
            elif status.mms_editing:
                new_number = ((status.mms_read_message.number[0][-1].split(':')[0] + ':') + self.ui.get_text())
                status.mms_read_message.number[0][-1] = new_number
                icon = uiconfig.baloon_mms_icon
            else:
                status.callee_terminal_number = self.ui.get_text()
                icon = uiconfig.baloon_message_icon
            stage = NotifyStage(_('Terminal number set'), icon)
            runtime.manager.change_stage(stage)



    def activate_menu2(self):
        runtime.manager.back_stage()



    def handle_key(self, key):
        if (key in '0123456789'):
            self.ui.handle_key(key)
            if (not self.our_terminal):
                self.ui.set_right(_('DELETE'))
            else:
                self.ui.set_right(_('BACK'))
            return True
        elif (key == config.Menu1):
            self.activate_menu1()
            return True
        elif (key == config.Menu2):
            if (self.ui.get_text() and (not self.our_terminal)):
                self.ui.delete_char()
                self.ui.set_right(_('BACK'))
                return True
            self.activate_menu2()
            return True
        return False



class SetTimeStage(Stage):
    __module__ = __name__

    def __init__(self, title, hourmin, done_cb):
        self.ui = ui.TimeEditUI(title, _('Set time:'), hourmin)
        self.done_cb = done_cb



    def handle_key(self, key):
        if (key == config.Menu1):
            self.done_cb(self.ui.time)
            return True
        else:
            return self.ui.handle_key(key)



class EmptyGalleryStage(NotifyStage):
    __module__ = __name__

class GalleryStage(Stage):
    __module__ = __name__

    def __init__(self, image_list, selected, done_cb):
        self.lists = image_list
        self.done_cb = done_cb
        self.current = selected
        self.ui = baseui.GalleryUI(_('OK'), _('BACK'), _('GALLERY - VIEW'))
        if (self.current >= 0):
            self.ui.set_preview(self.get_current_file())



    def get_current_file(self):
        return (self.base_dir + self.lists[self.current])



    def handle_key(self, key):
        if (key == config.Menu1):
            self.done_cb(self.current)
        elif (key == config.Menu2):
            runtime.manager.back_stage()
        elif (key == 'Up'):
            if (self.current > 0):
                self.current -= 1
            else:
                self.current = (len(self.lists) - 1)
            self.ui.set_preview(self.get_current_file())
        elif (key == 'Down'):
            if (self.current < (len(self.lists) - 1)):
                self.current += 1
            else:
                self.current = 0
            self.ui.set_preview(self.get_current_file())
        else:
            return False
        return True



    def show(self):
        self.ui._show_arrow = (len(self.lists) > 1)
        Stage.show(self)



class PINInputStage(Stage):
    __module__ = __name__

    def __init__(self, prefix, title, subtitle, digit_max_len = config.len_pin_number):
        self.digit_max_len = digit_max_len
        self.ui = ui.PINInputUI(prefix, title, subtitle, digit_max_len=self.digit_max_len)



    def handle_key(self, key):
        if (key == config.Menu1):
            if (len(self.ui.pin) == 0):
                return 
            if ((self.digit_max_len > 0) and (len(self.ui.pin) < self.digit_max_len)):
                return 
            self.activate(self.ui.pin)
        elif (key == config.Menu2):
            if (len(self.ui.pin) > 0):
                self.ui.delete_backward()
            else:
                runtime.manager.back_stage()
        else:
            self.ui.handle_key(key)



class RichTextStage(Stage):
    __module__ = __name__

    def __init__(self, title, left = _('OK'), right = _('BACK'), subtitle = '', font = uiconfig.richtext_font):
        self.ui = baseui.RichTextUI(left, right, title, subtitle, font)



    def set_text(self, text):
        self.ui.set_text(text)



    def activate_menu1(self):
        pass


    def activate_menu2(self):
        pass


    def handle_key(self, key):
        if (key == config.Menu1):
            self.activate_menu1()
        elif (key == config.Menu2):
            self.activate_menu2()
        else:
            return self.ui.handle_key(key)
        return True



class InfoT9Stage(Stage):
    __module__ = __name__

    def __init__(self):
        self.ui = baseui.InfoT9UI()



    def handle_key(self, key):
        if (key == 'Up'):
            self.ui.scroll_up()
            return True
        elif (key == 'Down'):
            self.ui.scroll_down()
            return True
        elif (key == config.Menu2):
            runtime.manager.back_stage()
        return False



class T9MessageNotify(NotifyStage):
    __module__ = __name__

    def __init__(self, msg):
        NotifyStage.__init__(self, msg, uiconfig.baloon_message_icon)



class T9AddWordStage(EntryStage):
    __module__ = __name__

    def __init__(self, editstage):
        EntryStage.__init__(self, _('Add word:'), '', left=_('OK'), right=_('BACK'))
        self.ui.set_max(32)
        self.set_fixed_automata('multitap_addword', 'lower')
        self.editstage = editstage
        self.ui.set_left('')



    def handle_key(self, key):
        ret = EntryStage.handle_key(self, key)
        if (ret and self.is_active()):
            if (self.ui.get_text() == ''):
                self.ui.set_left('')
            else:
                self.ui.set_left(_('OK'))
        return ret



    def activate_menu1(self):
        if self.ui.get_text():
            try:
                self.editstage.t9_add_word(self.ui.get_text())
            except StorageFullError:
                runtime.manager.change_stage(T9MessageNotify(_('T9 Storage is full')))
                return 
            runtime.manager.back_stage()



class RichTextEditStage(Stage):
    __module__ = __name__

    def __init__(self, title, small_title = '', left = _('OK'), right = _('BACK'), onlyview = False):
        self.ui = baseui.RichTextEditUI(left, right, title, small_title, onlyview=onlyview)
        self.onlyview = onlyview
        if self.onlyview:
            return 
        self.ui.set_automata(*utils.get_def_automata())
        self.automata_idx = utils.get_def_automata_idx()



    def show(self):
        status.editing = True
        Stage.show(self)



    def hide(self):
        status.editing = False
        Stage.hide(self)



    def destroy(self):
        status.editing = False
        Stage.destroy(self)



    def get_text(self):
        return self.ui.get_text()



    def activate_menu2(self):
        runtime.manager.back_stage()



    def t9_add_word(self, word):
        self.ui.edit.t9_add_word(word)



    def insert_symbol(self, s):
        self.ui.insert_text(s)



    def handle_key(self, key):
        if (key == config.Menu1):
            if self.ui.is_t9_add_word_mode():
                runtime.manager.stack_stage(T9AddWordStage(self))
                return True
            self.ui.reset_automata()
            self.activate_menu1()
        elif (key == config.Menu2):
            if self.ui.handle_key(key):
                return True
            if (self.ui.right == _('INFO T9')):
                runtime.manager.stack_stage(InfoT9Stage)
                return True
            else:
                self.activate_menu2()
        elif (key == '#'):
            if self.ui.is_t9_add_word_mode():
                return True
            self.automata_idx = utils.get_automata_idx(*self.ui.automata)
            self.automata_idx += 1
            if (self.automata_idx >= (len(config.automata_list) - 1)):
                self.automata_idx = 0
            (name, casemode,) = config.automata_list[self.automata_idx]
            self.ui.set_automata(name, casemode)
        elif ((key == '*') and (not self.ui.is_t9_editing_mode())):
            self.ui.reset_automata()
            runtime.manager.stack_stage(SymbolSelectionStage(self))
            return True
        else:
            return self.ui.handle_key(key)
        return True



class SymbolSelectionStage(Stage):
    __module__ = __name__

    def __init__(self, edit):
        self.ui = baseui.SymbolSelectionUI()
        self.edit = edit



    def handle_key(self, key):
        if self.ui.handle_key(key):
            return True
        if (key == config.Menu1):
            c = self.ui.get_symbol()
            self.edit.insert_symbol(c)
            runtime.manager.back_stage()
            return True
        elif (key == config.Menu2):
            runtime.manager.back_stage()
            return True
        return False




# local variables:
# tab-width: 4
