# emacs-mode: -*- python-*-
from basemodel import Stage, ListStage, YesNoStage, EntryStage, PINInputStage, NotifyStage
from model import StartCallStage, PhoneListBase, IdleStage
import runtime
import config
import uiconfig
import status
import utils
import setting
from setting import setting
from vdcisetting import vdcisetting
from phonedb import phonedb
from profile import profile, lan_profile, wifi_profile
import os
class LastCallStage(StartCallStage):
    __module__ = __name__
    number = '400'
    service_name = _('Last call')

class LastCallsStage(StartCallStage):
    __module__ = __name__
    number = '405'
    service_name = _('Last calls')

class Asterisk4Stage(StartCallStage):
    __module__ = __name__
    number = '4*'
    service_name = _('Service 4*')

class TAM1Stage(StartCallStage):
    __module__ = __name__
    number = '*63*1#'
    service_name = ((_('Answer machine:') + ' ') + _('Enable on no reply'))

class TAM2Stage(StartCallStage):
    __module__ = __name__
    number = '*63#'
    service_name = ((_('Answer machine:') + ' ') + _('Enable always'))

class TAMDisableStage(StartCallStage):
    __module__ = __name__
    number = '#63#'
    service_name = ((_('Answer machine:') + ' ') + _('Disable'))

class TAMCheckStatusStage(StartCallStage):
    __module__ = __name__
    number = '*#63#'
    service_name = ((_('Answer machine:') + ' ') + _('Check status'))

class TAMListenStage(StartCallStage):
    __module__ = __name__
    number = '*#64#'
    service_name = ((_('Answer machine:') + ' ') + _('Listen'))

class TAMAnswerAfterStage(ListStage):
    __module__ = __name__
    title = (_('ANSWER AFTER') + '...')
    choice = (_('1 ring'),
     _('2 rings'),
     _('3 rings'),
     _('4 rings'),
     _('5 rings'))
    left_labels = (_('CALL'),
     _('CALL'),
     _('CALL'),
     _('CALL'),
     _('CALL'))

    def __init__(self):
        ListStage.__init__(self)
        self.ui.set_left(self.left_labels[0])



    def activate(self, index):
        status.service_name = (((_('Answer machine:') + ' ') + _('Enable after ')) + self.choice[index])
        runtime.manager.start_call(('*63*0*%d#' % (index + 1)))



    def handle_key(self, key):
        return utils.offhk_dial_for_lists(self, key)



class TAMStage(ListStage):
    __module__ = __name__
    title = _('ANSWER MACHINE')
    choice = (_('Enable on no reply'),
     _('Enable always'),
     _('Disable'),
     _('Check status'),
     _('Listen'),
     _('Answer after...'))
    left_labels = (_('CALL'),
     _('CALL'),
     _('CALL'),
     _('CALL'),
     _('CALL'),
     _('OK'))

    def __init__(self):
        ListStage.__init__(self)
        self.ui.set_left(self.left_labels[0])



    def activate(self, index):
        stage = (TAM1Stage,
         TAM2Stage,
         TAMDisableStage,
         TAMCheckStatusStage,
         TAMListenStage,
         TAMAnswerAfterStage)[index]
        runtime.manager.stack_stage(stage)



    def handle_key(self, key):
        return utils.offhk_dial_for_lists(self, key)



class Info412Stage(StartCallStage):
    __module__ = __name__
    number = '1254'
    service_name = _('12.54')

class LogosStage(StartCallStage):
    __module__ = __name__
    number = '41412'
    service_name = _('Logos&Ringings')

class CallTransferDisableStage(StartCallStage):
    __module__ = __name__
    number = '#21#'
    service_name = _('Call transfer: Disable')

class CallTransferCheckStage(StartCallStage):
    __module__ = __name__
    number = '*#21#'
    service_name = _('Call transfer: Check status')


def CallTransferConfirmStage(number):

    def yes():
        setting.ct_number = number
        runtime.manager.start_call((('*21*' + number) + '#'))



    def no():
        runtime.manager.back_stage()


    message = (((_('Transfer to') + '\n') + number) + '?')
    stage = YesNoStage(message, yes, no, '', uiconfig.baloon_ti_service_icon)
    runtime.manager.stack_stage(stage)



def CallTransferPhoneListStage():
    import phonebook

    def activate(self, index):
        item = phonedb.get_item(index)
        (name, number, mobile,) = item[:3]
        if (number and mobile):

            def cb(number):
                CallTransferConfirmStage(number)


            stage = phonebook.DetailHideNumberStage(item, cb, isok=True)
            runtime.manager.stack_stage(stage)
            return 
        number = (number or mobile)
        if number:
            CallTransferConfirmStage(number)


    status.phonelist_activate = activate
    return phonebook.FindForCall2Stage()


class CallTransferEnableStage(EntryStage):
    __module__ = __name__

    def __init__(self):
        EntryStage.__init__(self, _('Number:'), _('CALL TRANSFER'), left=_('PHONEBOOK'))
        status.service_name = _('Call transfer: Enable')
        self.set_fixed_automata('123', False)
        self.ui.set_max(16)
        self.ui.set_text(setting.ct_number)
        if setting.ct_number:
            self.ui.set_left(_('OK'))



    def handle_key(self, key):
        ret = EntryStage.handle_key(self, key)
        if (ret and self.is_active()):
            if self.ui.get_text():
                self.ui.set_left(_('OK'))
            else:
                self.ui.set_left(_('PHONEBOOK'))
        return ret



    def activate_menu1(self):
        number = self.ui.get_text()
        if (not number):
            if (phonedb.count() == 0):
                import phonebook
                stage = phonebook.PhoneBookTempEmptyStage()
                runtime.manager.stack_stage(stage)
                return 
            elif phonedb.is_empty_for_call():
                import phonebook
                stage = phonebook.PhoneBookForCallEmptyStage()
                runtime.manager.stack_stage(stage)
                return 
            stage = CallTransferPhoneListStage()
            runtime.manager.stack_stage(stage)
            return 
        CallTransferConfirmStage(number)



class CallTransferStageForPSTN(ListStage):
    __module__ = __name__
    title = _('CALL TRANSFER')
    choice = (_('Enable'),
     _('Disable'),
     _('Check status'))
    left_labels = (_('OK'),
     _('CALL'),
     _('CALL'))

    def __init__(self):
        ListStage.__init__(self)
        self.ui.set_left(self.left_labels[0])



    def activate(self, index):
        stage = (CallTransferEnableStage,
         CallTransferDisableStage,
         CallTransferCheckStage)[index]
        runtime.manager.stack_stage(stage)



    def handle_key(self, key):
        return utils.offhk_dial_for_lists(self, key)




def SetCtNumber(kind, number):
    if (kind == 1):
        setting.ct_noreply_number = number
    elif (kind == 2):
        setting.ct_busy_number = number
    else:
        setting.ct_always_number = number



def GetCtNumber(kind):
    if (kind == 1):
        return setting.ct_noreply_number
    elif (kind == 2):
        return setting.ct_busy_number
    else:
        return setting.ct_always_number


class CallTransferDisableStageForAlice(StartCallStage):
    __module__ = __name__

    def __init__(self, kind):
        select_number = ('#21#',
         '#23#',
         '#22#')
        select_service_name = (_('Call transfer always:\nDisable'),
         _('Call transfer on no reply:\nDisable'),
         _('Call transfer on busy:\nDisable'))
        self.number = select_number[kind]
        self.service_name = select_service_name[kind]
        StartCallStage.__init__(self)



class CallTransferCheckStageForAlice(StartCallStage):
    __module__ = __name__

    def __init__(self, kind):
        select_number = ('*#21#',
         '*#23#',
         '*#22#')
        select_service_name = (_('Call transfer always:\nCheck status'),
         _('Call transfer on no reply:\nCheck status'),
         _('Call transfer on busy:\nCheck status'))
        self.number = select_number[kind]
        self.service_name = select_service_name[kind]
        StartCallStage.__init__(self)




def CallTransferConfirmStageForAlice(number, kind):
    select_number = ('*21*',
     '*23*',
     '*22*')
    select_service_name = (_('Transfer always to'),
     _('Transfer on no reply to'),
     _('Transfer on busy to'))
    code = select_number[kind]
    name = select_service_name[kind]

    def yes():
        SetCtNumber(kind, number)
        runtime.manager.start_call(((code + number) + '#'))



    def no():
        runtime.manager.back_stage()


    message = (((name + '\n') + number) + '?')
    stage = YesNoStage(message, yes, no, '', uiconfig.baloon_ti_service_icon)
    runtime.manager.stack_stage(stage)



def CallTransferPhoneListStageForAlice(kind):
    import phonebook

    def activate0(self, index):
        item = phonedb.get_item(index)
        (name, number, mobile,) = item[:3]
        if (number and mobile):

            def cb(number):
                CallTransferConfirmStageForAlice(number, 0)


            stage = phonebook.DetailHideNumberStage(item, cb, isok=True)
            runtime.manager.stack_stage(stage)
            return 
        number = (number or mobile)
        if number:
            CallTransferConfirmStageForAlice(number, 0)



    def activate1(self, index):
        item = phonedb.get_item(index)
        (name, number, mobile,) = item[:3]
        if (number and mobile):

            def cb(number):
                CallTransferConfirmStageForAlice(number, 1)


            stage = phonebook.DetailHideNumberStage(item, cb, isok=True)
            runtime.manager.stack_stage(stage)
            return 
        number = (number or mobile)
        if number:
            CallTransferConfirmStageForAlice(number, 1)



    def activate2(self, index):
        item = phonedb.get_item(index)
        (name, number, mobile,) = item[:3]
        if (number and mobile):

            def cb(number):
                CallTransferConfirmStageForAlice(number, 2)


            stage = phonebook.DetailHideNumberStage(item, cb, isok=True)
            runtime.manager.stack_stage(stage)
            return 
        number = (number or mobile)
        if number:
            CallTransferConfirmStageForAlice(number, 2)


    status.phonelist_activate = (activate0,
     activate1,
     activate2)[kind]
    return phonebook.FindForCall2Stage()


class CallTransferEnableStageForAlice(EntryStage):
    __module__ = __name__

    def __init__(self, kind):
        EntryStage.__init__(self, _('Number:'), _('CALL TRANSFER'), left=_('PHONEBOOK'))
        service_name = (_('Call transfer always:\nEnable'),
         _('Call transfer on no reply:\nEnable'),
         _('Call transfer on busy:\nEnable'))
        status.service_name = service_name[kind]
        self.set_fixed_automata('123', False)
        self.ui.set_max(16)
        self.kind = kind
        ct_number = GetCtNumber(kind)
        self.ui.set_text(ct_number)
        if ct_number:
            self.ui.set_left(_('OK'))



    def handle_key(self, key):
        ret = EntryStage.handle_key(self, key)
        if (ret and self.is_active()):
            if self.ui.get_text():
                self.ui.set_left(_('OK'))
            else:
                self.ui.set_left(_('PHONEBOOK'))
        return ret



    def activate_menu1(self):
        number = self.ui.get_text()
        if (not number):
            if (phonedb.count() == 0):
                import phonebook
                stage = phonebook.PhoneBookTempEmptyStage()
                runtime.manager.stack_stage(stage)
                return 
            elif phonedb.is_empty_for_call():
                import phonebook
                stage = phonebook.PhoneBookForCallEmptyStage()
                runtime.manager.stack_stage(stage)
                return 
            stage = CallTransferPhoneListStageForAlice(self.kind)
            runtime.manager.stack_stage(stage)
            return 
        CallTransferConfirmStageForAlice(number, self.kind)



class CallTransferSelectStageForAlice(ListStage):
    __module__ = __name__

    def __init__(self, kind):
        self.kind = kind
        subtitle = (_('ALWAYS'),
         _('ON NO REPLY'),
         _('ON BUSY'))
        self.left_labels = (_('OK'),
         _('CALL'),
         _('CALL'))
        title = _('CALL TRANSFER')
        choice = (_('Enable'),
         _('Disable'),
         _('Check status'))
        ListStage.__init__(self, choice, title)
        self.ui.set_left(self.left_labels[0])



    def activate(self, index):
        stage = (CallTransferEnableStageForAlice,
         CallTransferDisableStageForAlice,
         CallTransferCheckStageForAlice)[index](self.kind)
        runtime.manager.stack_stage(stage)



    def handle_key(self, key):
        return utils.offhk_dial_for_lists(self, key)



class CallTransferStageForAlice(ListStage):
    __module__ = __name__
    title = _('CALL TRANSFER')
    choice = (_('Always'),
     _('On no reply'),
     _('On busy'))

    def __init__(self):
        ListStage.__init__(self)
        self.ui.set_left(_('OPTIONS'))



    def activate(self, index):
        stage = CallTransferSelectStageForAlice(index)
        runtime.manager.stack_stage(stage)



class CallWaitingStage(ListStage):
    __module__ = __name__
    title = _('CALL WAITING')
    choice = (_('Enable'),
     _('Disable'),
     _('Check status'))
    left_labels = (_('CALL'),
     _('CALL'),
     _('CALL'))

    def __init__(self):
        ListStage.__init__(self)
        self.ui.set_left(self.left_labels[0])



    def activate(self, index):
        number = ('*43#',
         '#43#',
         '*#43#')[index]
        status.service_name = (_('Call waiting: Enable'),
         _('Call waiting: Disable'),
         _('Call waiting: Check status'))[index]
        runtime.manager.start_call(number)



    def handle_key(self, key):
        return utils.offhk_dial_for_lists(self, key)



class CorrectTimeStage(StartCallStage):
    __module__ = __name__
    number = '4161'
    service_name = _('Correct time')

class WakeUpCallsStage(StartCallStage):
    __module__ = __name__
    number = '4114'
    service_name = _('Wake up call')

class ChiarotelStage(StartCallStage):
    __module__ = __name__
    number = '4717'
    service_name = _('Chiarotel')

class UrgentCallStage(StartCallStage):
    __module__ = __name__
    number = '4197'
    service_name = _('Urgent call')

class Service5Stage(ListStage):
    __module__ = __name__
    title = _('SERVICE 5')
    choice = (_('Disable'),
     _('Check status'))
    left_labels = (_('CALL'),
     _('CALL'))

    def __init__(self):
        ListStage.__init__(self)
        self.ui.set_left(self.left_labels[0])



    def activate(self, index):
        number = ('#37#',
         '*#37#')[index]
        status.service_name = (_('Service 5: Disable'),
         _('Service 5: Check status'))[index]
        runtime.manager.start_call(number)



    def handle_key(self, key):
        return utils.offhk_dial_for_lists(self, key)



class AutoDisPINCheckStage(PINInputStage):
    __module__ = __name__

    def __init__(self):
        PINInputStage.__init__(self, '', _('CALL BARRING'), (_('SERVICE PIN') + ':'))



    def activate(self, pin):
        status.service_name = _('Call barring: Disable')
        status.visual_number = (('#33*' + ('*' * len(pin))) + '#')
        runtime.manager.start_call((('#33*' + pin) + '#'))
        return 



class AutoDisabilitazioneStage(ListStage):
    __module__ = __name__
    title = _('CALL BARRING')
    choice = (_('Enable'),
     _('Disable'),
     _('Check status'))
    left_labels = (_('CALL'),
     _('OK'),
     _('CALL'))

    def __init__(self):
        ListStage.__init__(self)
        self.ui.set_left(self.left_labels[0])



    def activate(self, index):
        if (index == 1):
            stage = AutoDisPINCheckStage
            runtime.manager.stack_stage(stage)
            return 
        number = ('*33#',
         0,
         '*#33#')[index]
        status.service_name = (_('Call barring: Enable'),
         '',
         _('Call barring: Check status'))[index]
        runtime.manager.start_call(number)



    def handle_key(self, key):
        return utils.offhk_dial_for_lists(self, key)



class MultiNumberEditStage(EntryStage):
    __module__ = __name__

    def __init__(self, title):
        EntryStage.__init__(self, _('Number:'), title, left=_('OK'), right=_('BACK'))
        self.set_fixed_automata('123', False)
        self.ui.set_max(20)
        self.ui.set_left('')



    def activate_menu1(self):
        number = self.ui.get_text()
        if (not number):
            return 
        call_number = ('#*##*#*P%d1*%s#' % ((status.multi_number_port + 1),
         number))
        status.service_name = _('Multi-number')
        runtime.manager.start_call(call_number)



    def handle_key(self, key):
        if (key == config.OffHook):
            if (not self.ui.get_text()):
                return False
            runtime.netif.set_audio_state_op(status.HS)
            runtime.netif.offhook_hs()
            self.activate_menu1()
            return True
        elif (key == config.Green):
            index = self.ui.get_focus()
            if (not self.ui.get_text()):
                return False
            runtime.netif.set_audio_state_op(status.SPK)
            runtime.netif.offhook_spk()
            self.activate_menu1()
            return True
        ret = EntryStage.handle_key(self, key)
        if (ret and self.is_active()):
            if self.ui.get_text():
                self.ui.set_left(_('CALL'))
            else:
                self.ui.set_left('')
        return ret



class MultiNumberStage(ListStage):
    __module__ = __name__
    choice = ((_('Analog port') + ' 1'),
     (_('Analog port') + ' 2'))
    title = _('MULTI-NUMBER')

    def activate(self, index):
        status.multi_number_port = index
        titles = ((_('ANALOG PORT') + ' 1'),
         (_('ANALOG PORT') + ' 2'))
        stage = MultiNumberEditStage(titles[index])
        runtime.manager.change_stage(stage)



class CidEnableNotifyStage(YesNoStage):
    __module__ = __name__

    def __init__(self, number):
        self.number = number
        icon = uiconfig.baloon_phone_setting_icon
        YesNoStage.__init__(self, _('Remember: you can choose a\n"Vocal caller ID" through\n"Phone settings options"'), self.yes_cb, self.no_cb, '', icon)
        self.ui.set_right('')
        self.ui.set_left(_('OK'))



    def yes_cb(self):
        runtime.manager.start_call(self.number)



    def no_cb(self):
        pass


class CIDStage(ListStage):
    __module__ = __name__
    title = _('CALLER ID')
    choice = (_('Enable'),
     _('Disable'),
     _('Check status'))
    left_labels = (_('OK'),
     _('CALL'),
     _('CALL'))

    def __init__(self):
        ListStage.__init__(self)
        self.ui.set_left(self.left_labels[0])



    def activate(self, index):
        number = ('*65#',
         '#65#',
         '*#65#')[index]
        status.service_name = (_('Caller ID: Enable'),
         _('Caller ID: Disable'),
         _('Caller ID: Check status'))[index]
        if (index == 0):
            stage = CidEnableNotifyStage(number)
            runtime.manager.change_stage(stage)
        else:
            runtime.manager.start_call(number)



    def handle_key(self, key):
        return utils.offhk_dial_for_lists(self, key)




def HideNumberConfirm(number, name):

    def yes():
        runtime.manager.start_call((config.hidden_number_prefix + number))



    def no():
        runtime.manager.back_stage()


    message = ((_('Hide number to ') + ('%s' % number)) + '?')
    stage = YesNoStage(message, yes, no, '', uiconfig.baloon_ti_service_icon)
    runtime.manager.stack_stage(stage)



def HideNumberPhoneListStage():

    def activate(self, index):
        print 'hide number phone list stage activate'
        item = phonedb.get_item(index)
        (name, number, mobile,) = item[:3]
        if (number and mobile):

            def cb(number):
                HideNumberConfirm(number, name)


            stage = phonebook.DetailHideNumberStage(item, cb, isok=True)
            runtime.manager.stack_stage(stage)
            return 
        number = (number or mobile)
        if number:
            HideNumberConfirm(number, name)


    status.phonelist_activate = activate
    import phonebook
    return phonebook.FindForCall2Stage()


class HideNumberStage(EntryStage):
    __module__ = __name__

    def __init__(self):
        EntryStage.__init__(self, _('Number:'), _('HIDE NUMBER'), left=_('PHONEBOOK'))
        self.set_fixed_automata('123', False)
        self.ui.set_max(20)



    def handle_key(self, key):
        print 'hidenumber stage: handle key',
        print key
        ret = EntryStage.handle_key(self, key)
        if (ret and self.is_active()):
            if self.ui.get_text():
                self.ui.set_left(_('OK'))
            else:
                self.ui.set_left(_('PHONEBOOK'))
        return ret



    def activate_menu1(self):
        number = self.ui.get_text()
        if (not number):
            if (phonedb.count() == 0):
                import phonebook
                stage = phonebook.PhoneBookTempEmptyStage()
                runtime.manager.stack_stage(stage)
                return 
            elif phonedb.is_empty_for_call():
                import phonebook
                stage = phonebook.PhoneBookForCallEmptyStage()
                runtime.manager.stack_stage(stage)
                return 
            stage = HideNumberPhoneListStage
            runtime.manager.stack_stage(stage)
            return 
        HideNumberConfirm(number, number)



class ManualInsertion(EntryStage):
    __module__ = __name__

    def __init__(self):
        EntryStage.__init__(self, _("Network's name"), _('MANUAL INSERTION'))
        self.ui.set_left('')
        self.scan_info = []
        self.ui.automata_idx = 0
        (name, casemode,) = config.automata_list2[self.ui.automata_idx]
        self.ui.set_automata(name, casemode)



    def handle_key(self, key):
        if ((key == '#') and (not self.ui.fixed_automata)):
            if self.ui.is_t9_add_word_mode():
                return True
            self.ui.automata_idx = utils.get_automata_idx2(*self.ui.automata)
            self.ui.automata_idx += 1
            if (self.ui.automata_idx >= len(config.automata_list2)):
                self.ui.automata_idx = 0
            (name, casemode,) = config.automata_list2[self.ui.automata_idx]
            self.ui.set_automata(name, casemode)
            return True
        ret = EntryStage.handle_key(self, key)
        if (ret and self.is_active()):
            if self.ui.get_text():
                self.ui.set_left(_('OK'))
            else:
                self.ui.set_left('')



    def activate_menu1(self):
        if (self.ui.left == _('OK')):
            ssid = self.ui.get_text()
            self.scan_info = self.check_ssid(ssid)
            if (self.scan_info != []):
                wifi_profile.set_essid(self.scan_info[0][2])
                wifi_profile.set_chid(self.scan_info[0][3])
                wifi_profile.save()
                profile.set_profile(profile.WIFI)
                runtime.manager.change_stage(IdleStage, True)
                InitializeCheckWifi()
            else:
                stage = AliceNotifyStage(_('Network not available'))
                runtime.manager.stack_stage(stage)
            return True



    def check_ssid(self, ssid):
        searchstr = '/usr/local/bin/checkwifiscan'
        import os
        fname = os.popen(searchstr)
        wifi_info = []
        for tline in fname:
            if (tline.find('ESSID') > 0):
                (a, b,) = tline.split(':')
                b = b.strip()
                b = b[1:(len(b) - 1)]
                info.append(b)
            elif (tline.find('Address') > 0):
                info = []
                info.append(tline[:tline.find('-')].strip())
                info.append(tline[(tline.find(':') + 1):].strip())
            elif (tline.find('Channel') > 0):
                ti = tline.find('Channel')
                info.append(tline[(ti + 7):tline.find(')')].strip())
            elif (tline.find('Signal level') > 0):
                ti = tline.find('Signal level')
                info.append(tline[(ti + 13):(tline.find('dBm', ti) + 3)])
            elif (tline.find('Encryption key') > 0):
                (a, b,) = tline.split(':')
                info.append(b.strip())
                if (info[2] == ssid):
                    wifi_info.append(info)

        fname.close()
        return wifi_info



class DisplayNetwork(ListStage):
    __module__ = __name__

    def __init__(self, lists, title, scan_info, poweron = False):
        ListStage.__init__(self, lists, title)
        self.scan_info = scan_info
        self.lists = lists
        self.poweron = poweron
        if self.poweron:
            self.ui.set_title(_('SELECT NETWORK'))
            self.ui.set_left(_('OK'))
            self.ui.set_right(_('RETRY'))



    def show(self):
        if (len(self.lists) == 0):
            stage = WifiScanNoListStage
            runtime.manager.change_stage(stage)
            return 
        ListStage.show(self)



    def activate(self, index):
        wifi_profile.set_essid(self.scan_info[index][2])
        wifi_profile.set_chid(self.scan_info[index][3])
        wifi_profile.save()
        print 'SSID=',
        print self.scan_info[index][2],
        print 'CH=',
        print self.scan_info[index][3]
        if (not self.poweron):
            profile.set_profile(profile.WIFI)
            runtime.manager.change_stage(IdleStage, True)
            self.poweron = True
        if self.poweron:
            if (self.scan_info[index][5] == 'on'):
                message = _('Press Registration button\n(Reg) on wi-fi module')
                stage = AliceNotifyStage(message, check_reg_pressed, exit_to_idle=True)
                runtime.manager.change_stage(stage)
            else:
                wifi_profile.encryption = 'NONE'
                wifi_profile.save()
                message = ((_('Network selected') + '\n') + _('Please wait...'))
                os.system('/usr/local/bin/start_profile')
                stage = AliceNotifyStage(message, check_ipaddr, exit_to_idle=True)
                runtime.manager.change_stage(stage)
        else:
            runtime.manager.back_stage()



    def handle_key(self, key):
        if ((key == config.Menu2) and self.poweron):
            stage = AllNetwork(self.poweron)
            runtime.manager.stack_stage(stage)
            return 
        ListStage.handle_key(self, key)




def ScanNetwork(title, poweron = False):

    def info_get(fname, isalice):
        wifi_info = []
        for tline in fname:
            if (tline.find('ESSID') > 0):
                (a, b,) = tline.split(':')
                b = b.strip()
                b = b[1:(len(b) - 1)]
                info.append(b)
            elif (tline.find('Address') > 0):
                info = []
                info.append(tline[:tline.find('-')].strip())
                info.append(tline[(tline.find(':') + 1):].strip())
            elif (tline.find('Channel') > 0):
                ti = tline.find('Channel')
                info.append(tline[(ti + 7):tline.find(')')].strip())
            elif (tline.find('Signal level') > 0):
                ti = tline.find('Signal level')
                info.append(tline[(ti + 13):(tline.find('dBm', ti) + 3)])
            elif (tline.find('Encryption key') > 0):
                (a, b,) = tline.split(':')
                info.append(b.strip())
                if info[2]:
                    if isalice:
                        if info[2].startswith('Alice'):
                            wifi_info.append(info)
                    else:
                        wifi_info.append(info)

        return wifi_info


    try:
        import os
        searchstr = '/usr/local/bin/checkwifiscan'
        fp = os.popen(searchstr)
        if (title == _('ALICE NETWORKS')):
            scan_info = info_get(fp, 1)
        else:
            scan_info = info_get(fp, 0)
        if (scan_info != []):
            cwifi = len(scan_info)
            lists = []
            for z in range(cwifi):
                lists.append(scan_info[z][2])

            stage = DisplayNetwork(lists, title, scan_info, poweron)
        else:
            stage = WifiScanNoListStage
            print 'Any AP cannot search.'
        fp.close()
    except:
        stage = AliceNotifyStage('No network available')
    return stage



def AllNetwork(poweron = False):
    return ScanNetwork(_('ALL NETWORKS'))



def AliceNetwork():
    return ScanNetwork(_('ALICE NETWORKS'))



def check_ipaddr():
    message = _('Please wait...')
    setting.reset_screen_saver_timer()
    stage = AliceNotifyStage(message, res_ipaddr, exit_to_idle=True)
    runtime.manager.change_stage(stage)



def res_ipaddr():
    ret = os.system('/usr/local/bin/start_dhcp')
    print (' ### start dhcp return = ' + str(ret))
    if (ret != 0):
        message = _('Connection error')
        stage = AliceNotifyStage(message, check_ipaddr, exit_to_idle=True)
        runtime.manager.change_stage(stage)
        return 
    status.LanConnected = True
    import time
    status.linkup_time = time.time()
    if (profile.get_profile() == profile.WIFI):
        dhcpinfo = utils.get_dhcpinfo('wlan0')
    else:
        dhcpinfo = utils.get_dhcpinfo('eth0')
    try:
        stun_server = dhcpinfo['AGURL'].replace("'", '')
        temp = stun_server.split(':')
        stun_server = temp[1][2:]
    except:
        stun_server = config.stun_server

    def do_stun():
        cmd = ('stund %s:3478 -p 1500 -m' % stun_server)
        print cmd
        os.system(cmd)
        os.system(cmd)
        return True


    InitializeCheckAPTCPforCLI(directcall=False)
    import server
    if runtime.tr069If:
        os.system('killall -9 dimclient')
    else:
        runtime.tr069If = server.Tr069If()



def check_reg_pressed():
    stage = WifiPressRegStage
    runtime.manager.change_stage(stage)
    return 



def select_network():
    message = ((_('Network selected') + '\n') + _('Please wait...'))
    stage = AliceNotifyStage(message, wait_activation, exit_to_idle=True)
    runtime.manager.change_stage(stage)
    return 



def wait_activation():
    message = _('Please wait...')
    setting.reset_screen_saver_timer()
    stage = AliceNotifyStage(message, activation_result, exit_to_idle=True)
    runtime.manager.change_stage(stage)
    return 



def activation_result():
    message = ((_('Activation code accepted') + '\n') + _('Please wait...'))
    os.system('/usr/local/bin/start_profile')
    stage = AliceNotifyStage(message, check_ipaddr, exit_to_idle=True)
    runtime.manager.change_stage(stage)
    return 



def check_security_config():
    res = []
    if (wifi_profile.encryption == 'WEP128BIT'):
        res.append(1)
        if (len(wifi_profile.wepkey1_128) > 0):
            res.append(1)
        else:
            res.append(0)
    elif (wifi_profile.authentication == 'WPA-PSK'):
        res.append(1)
        if (len(wifi_profile.wpa_psk_tkip) > 0):
            res.append(1)
        else:
            res.append(0)
    else:
        res.append(0)
        res.append(0)
    return tuple(res)


class NetworksList(ListStage):
    __module__ = __name__
    title = _("NETWORKS' LIST")
    choice = (_('Alice networks'),
     _('All networks'))

    def activate(self, index):
        stage = (AliceNetwork,
         AllNetwork)[index]
        runtime.manager.stack_stage(stage())



class SelectNetworkStage(ListStage):
    __module__ = __name__
    title = _('SELECT NETWORK')
    choice = (_('Manual insertion'),
     _("networks' list"))

    def activate(self, index):
        stage = (ManualInsertion,
         NetworksList)[index]
        runtime.manager.stack_stage(stage)



class ActivationCodeStage(EntryStage):
    __module__ = __name__

    def __init__(self, poweron = False):
        EntryStage.__init__(self, _('Activation code'), _('ALICE'))
        self.ui.set_max(24)
        self.ui.set_automata('123', False)
        self.poweron = poweron
        if self.poweron:
            self.ui.set_title(_('SUBSCRIPTION'))
            self.ui.set_right(_('EXIT'))



    def activate_menu1(self):
        code = self.ui.get_text()
        if (len(code) == 13):
            if ((wifi_profile.encryption == 'WEP128BIT') and (wifi_profile.wepkey1_128 == code)):
                stage = AliceNotifyStage(_('No change'))
                if (not self.poweron):
                    runtime.manager.back_stage()
                    runtime.manager.back_stage()
                    runtime.manager.change_stage(stage)
            else:
                wifi_profile.encryption = 'WEP128BIT'
                wifi_profile.authentication = 'NONE'
                wifi_profile.wepkeyno_128 = 1
                wifi_profile.wepkey1_128 = code
                wifi_profile.wpa_psk_tkip = ''
                wifi_profile.save()
                if (not self.poweron):
                    stage = AliceNotifyStage(((_('Activation code accepted') + '\n') + _('Please wait...')))
                    runtime.manager.change_stage(stage)
        elif (len(code) == 24):
            if (wifi_profile.wpa_psk_tkip == code):
                stage = AliceNotifyStage(_('No change'))
                if (not self.poweron):
                    runtime.manager.back_stage()
                    runtime.manager.back_stage()
                    runtime.manager.change_stage(stage)
            else:
                wifi_profile.authentication = 'WPA-PSK'
                wifi_profile.encryption = 'NONE'
                wifi_profile.wepkey1_128 = ''
                wifi_profile.wpa_psk_tkip = code
                wifi_profile.save()
                if (not self.poweron):
                    stage = AliceNotifyStage(((_('Activation code accepted') + '\n') + _('Please wait...')))
                    runtime.manager.change_stage(stage)
        else:
            stage = AliceNotifyStage(((_('Wrong activation code') + '\n') + _('Please wait...')))
            runtime.manager.stack_stage(stage)
            return True
        if self.poweron:
            message = _('Please wait...')
            setting.reset_screen_saver_timer()
            stage = AliceNotifyStage(message, select_network)
            runtime.manager.change_stage(stage)
        return True




def InitializeCheckWifi():
    if ((len(wifi_profile.essid) == 0) or (len(wifi_profile.encryption) == 0)):
        stage = AllNetwork(poweron=True)
        runtime.manager.stack_stage(stage)
        runtime.evas.render_now()
    else:
        (mode, iskey,) = check_security_config()
        if (mode != 0):
            if iskey:
                message = _('Please wait...')
                setting.reset_screen_saver_timer()
                stage = AliceNotifyStage(message, select_network, exit_to_idle=True)
                runtime.manager.change_stage(stage)
            else:

                def check_reg_pressed():
                    stage = WifiPressRegStage
                    runtime.manager.change_stage(stage)
                    return 


                message = _('Press Registration button\n(Reg) on wi-fi module')
                stage = AliceNotifyStage(message, check_reg_pressed, exit_to_idle=True)
                runtime.manager.change_stage(stage)
        else:
            message = ((_('Network selected') + '\n') + _('Please wait...'))
            os.system('/usr/local/bin/start_profile')
            stage = AliceNotifyStage(message, check_ipaddr, exit_to_idle=True)
            runtime.manager.change_stage(stage)



def InitializeCheckAPTCPforCLI(directcall = True):
    if os.path.exists('/usr/etc/testmode5'):
        if runtime.vdciapp:
            runtime.vdciapp.kill_vdciapp()
            runtime.vdciapp = None
        runtime.manager.net_init()
        runtime.manager.back_stage('idle')
        return 
    if (profile.get_profile() == profile.PSTN):
        return 
    value = vdcisetting.CLI
    if (value != ''):
        print ('InitializeCheckAPTCPforCLI val = ' + value)
        stage = ModifyTelephoneNumberSetStage(value, retry=True)
    else:
        stage = CHK_ModifyTelephoneNumberStage()
    if directcall:
        runtime.manager.stack_stage(stage)
    else:
        runtime.manager.change_stage(stage)



def InitializeCheckTR069forURL(directcall = True):
    print 'InitializeCheckTR069forURL'
    os.system('rm -rf /usr/etc/tr069/eventCodeP.dat')
    os.system('rm -rf /tmp/stun.info')
    os.system('touch /tmp/lock')
    os.system('killall stund')
    os.system('killall dimclient')
    os.system('rm -rf /tmp/lock')



def InitializeCheckTR069forCLI(directcall = True):
    if os.path.exists('/usr/etc/testmode5'):
        if runtime.vdciapp:
            runtime.vdciapp.kill_vdciapp()
            runtime.vdciapp = None
        runtime.manager.net_init()
        runtime.manager.back_stage('idle')
        return 
    if (profile.get_profile() == profile.PSTN):
        return 
    value = vdcisetting.CLI
    if (value != ''):
        print ('InitializeCheckTR069forCLI val = ' + value)
        if runtime.vdciapp:
            runtime.vdciapp.kill_vdciapp()
            runtime.vdciapp = None
        runtime.manager.net_init()
    else:
        stage = ModifyTelephoneNumberStage()
    if directcall:
        runtime.manager.stack_stage(stage)
    else:
        runtime.manager.change_stage(stage)



def InitializeCheckAGONforCLI(directcall = True):
    if runtime.aptcp:
        runtime.aptcp.aptcp_close()
        runtime.aptcp = None
    print 'InitializeCheckAGONforCLI'
    os.system('rm -rf /tmp/stun.info')
    os.system('touch /tmp/lock')
    os.system('killall stund')
    os.system('killall dimclient')
    if (profile.get_profile() == profile.WIFI):
        dhcpinfo = utils.get_dhcpinfo('wlan0')
    else:
        dhcpinfo = utils.get_dhcpinfo('eth0')
    try:
        stun_server = dhcpinfo['AGURL'].replace("'", '')
        temp = stun_server.split(':')
        stun_server = temp[1][2:]
    except:
        stun_server = config.stun_server

    def do_stun():
        cmd = ('stund %s:3478 -p 1500 -m' % stun_server)
        cnt = 0
        while 1:
            try:
                print cmd
                ret = os.system(cmd)
                if (ret == 0):
                    if os.path.exists('/tmp/stun.info'):
                        return True
                cnt += 1
                if (cnt > 2):
                    return True
            except:
                return 

        return True


    InitializeCheckAPTCPforCLI()
    os.system('rm -rf /tmp/lock')


import aptcp

def setproxy(proxy, checknull = False):
    if ((not proxy) or (len(proxy) == 0)):
        return 
    if (checknull and vdcisetting.proxyAddress):
        print 'Already set proxy :',
        print vdcisetting.proxyAddress
        return 
    vdcisetting.proxyAddress = proxy



def setCli(cli):
    vdcisetting.CLI = cli



def setSipkey(sipKey):
    vdcisetting.sipKey = sipKey



def setSipDomain(domain, checknull = False):
    if ((not domain) or (len(domain) == 0)):
        if (not vdcisetting.domain):
            vdcisetting.domain = 'Aliceunica.telecomitalia.it'
        return 
    if (checknull and vdcisetting.domain):
        print 'Already set domain :',
        print vdcisetting.domain
        return 
    vdcisetting.domain = domain



def setauthRealm(authrealm, checknull = False):
    if ((not authrealm) or (len(authrealm) == 0)):
        if (not vdcisetting.authRealm):
            vdcisetting.authRealm = 'digest.telecomitalia.it'
        return 
    if (checknull and vdcisetting.authRealm):
        print 'Already set authRealm :',
        print vdcisetting.authRealm
        return 
    vdcisetting.authRealm = authrealm


class ModifyTelephoneNumberManualStage(EntryStage):
    __module__ = __name__
    mame = 'cli set'

    def __init__(self):
        EntryStage.__init__(self, _('number'), _('SUBSCRIPTION'))
        self.ui.set_max(20)
        self.set_fixed_automata('123', False)
        self.update_softkey()



    def update_softkey(self):
        if (len(self.ui.get_text()) > 0):
            self.ui.set_left(_('OK'))
            self.ui.set_right(_('DELETE'))
        else:
            self.ui.set_left('')
            self.ui.set_right(_('EXIT'))



    def show(self):
        self.update_softkey()
        EntryStage.show(self)



    def activate_menu1(self):
        text = self.ui.get_text()
        if (len(text) == 0):
            print 'no text'
            return 
        stage = ModifyTelephoneNumberSetStage(text)
        runtime.manager.stack_stage(stage)



    def handle_key(self, key):
        if (key == config.Menu1):
            self.activate_menu1()
            return 
        elif ((self.ui.right == _('EXIT')) and (key == config.Menu2)):
            runtime.manager.back_stage('idle')
            return 
        EntryStage.handle_key(self, key)




def CHK_ModifyTelephoneNumberStage():
    utils.AdslLinkCheck()
    if status.LanConnected:
        stage = ModifyTelephoneNumberStage
    else:
        stage = AliceNotifyStage(_('ADSL line not connected\nor not available'), noexit=True)
    return stage


class ModifyTelephoneNumberStage(ListStage):
    __module__ = __name__
    title = _('SELECT NUMBER')
    mame = 'cli set'

    def __init__(self):
        ListStage.__init__(self, self.get_choice())
        self.ui.create_icon_column(uiconfig.sdmmc_explorer_icon_x, self.icons)



    def get_choice(self):
        self.icons = []
        choice = []
        self.info = aptcp.RequestCLI()
        print ('self.info = ' + str(self.info))
        if (self.info and (len(self.info.clilist) > 0)):
            choice = map(lambda x:x[1]
, self.info.clilist)

            def mapicons(x):
                print ('x[0] = ' + str(x[0]))
                if (x[1] == vdcisetting.CLI):
                    return uiconfig.cli_selected
                if (x[0] == 'Registered'):
                    return uiconfig.cli_registered
                return None


            self.icons = map(mapicons, self.info.clilist)
            print ('icons = ' + str(self.icons))
        self.choice = choice
        return choice



    def show(self):
        if (len(self.choice) == 0):
            print 'no cid info available : manual cid input'
            stage = ModifyTelephoneNumberManualStage
            runtime.manager.change_stage(stage)
            return 
        ListStage.show(self)
        index = self.ui.get_focus()
        if (self.icons[index] == None):
            self.ui.set_left(_('OK'))
        elif (self.icons[index] == uiconfig.cli_selected):
            self.ui.set_left(_('RELEASE'))
        else:
            self.ui.set_left('')



    def activate(self, index):
        if (self.info.clilist[index][1] == vdcisetting.CLI):
            stage = ReleaseTelephoneNumberYesNoStage()
            runtime.manager.stack_stage(stage)
        elif (self.info.clilist[index][0] == 'Registered'):
            return 
        elif (self.info.clilist[index][0] == 'Available'):
            if vdcisetting.CLI:
                stage = ModifyTelephoneNumberYesNoStage(self.info.clilist[index][1])
            else:
                stage = ModifyTelephoneNumberSetStage(self.info.clilist[index][1])
            runtime.manager.stack_stage(stage)



    def handle_key(self, key):
        if ((key == config.Menu2) or (key == config.Red)):
            runtime.manager.back_stage('idle')
            return True
        ret = ListStage.handle_key(self, key)
        if (ret and (key in ('Up',
         'Down'))):
            index = self.ui.get_focus()
            if (self.icons[index] == None):
                self.ui.set_left(_('OK'))
            elif (self.icons[index] == uiconfig.cli_selected):
                self.ui.set_left(_('RELEASE'))
            else:
                self.ui.set_left('')
        return ret



class ReleaseTelephoneNumberYesNoStage(YesNoStage):
    __module__ = __name__
    name = 'release cli yesno'

    def __init__(self):
        message = ((((_('Release the number') + '\n') + vdcisetting.CLI) + ' ') + _('assigned to\nVideophone?'))
        YesNoStage.__init__(self, message, self.yes_cb, self.no_cb, '', uiconfig.baloon_alice_icon)



    def yes_cb(self):
        stage = ReleaseTelephoneNumberStage()
        runtime.manager.change_stage(stage)



    def no_cb(self):
        runtime.manager.back_stage()



class ReleaseTelephoneNumberStage(Stage):
    __module__ = __name__

    def show(self):
        if runtime.vdciapp:
            runtime.vdciapp.send_mesg(config.MESG_UNREGISTER)
            status.register_status = status.NotRegistered
        stage = AliceNotifyStage(_('Please wait...'))
        runtime.manager.change_stage(stage)
        runtime.evas.render_now()
        try:
            info = aptcp.DelCLI()
            if (not info):
                raise IOError
        except:
            print 'DelCLI error !!!'
        vdcisetting.CLI = ''
        vdcisetting._save()
        status.register_status = status.NotRegistered
        stage = AliceNotifyStage(_('Number released. To make\nand receive calls switch\nto ADSL or telephone line.'), runtime.manager.back_stage('idle'), exit_to_idle=True)
        runtime.manager.change_stage(stage)



    def handle_key(self, key):
        print 'handle key'



    def destroy(self):
        print 'destroy'



class ModifyTelephoneNumberYesNoStage(YesNoStage):
    __module__ = __name__
    name = 'modify cli yesno'

    def __init__(self, cli):
        self.cli = cli
        message = ((((((_('Replace current number') + '\n') + vdcisetting.CLI) + ' ') + _('with')) + ' ') + cli)
        YesNoStage.__init__(self, message, self.yes_cb, self.no_cb, '', uiconfig.baloon_alice_icon)



    def yes_cb(self):
        stage = ModifyTelephoneNumberSetStage(self.cli)
        runtime.manager.change_stage(stage)



    def no_cb(self):
        runtime.manager.back_stage()



class ModifyTelephoneNumberSetStage(Stage):
    __module__ = __name__

    def __init__(self, cli, retry = False):
        self.cli = cli
        self.retry = retry
        if runtime.vdciapp:
            runtime.vdciapp.send_mesg(config.MESG_UNREGISTER)
            status.register_status = status.NotRegistered



    def show(self):
        try:
            if (runtime.aptcp == None):
                print 'aptcp_recv launching...'
                runtime.aptcp = aptcp.APTCPReciever()
                runtime.aptcp.run_aptcp_recv()
            info = aptcp.SetCLI(self.cli)
            if (not info):
                raise IOError
            errcode = int(info.errorlist[0][1])
            print ('errlist = ' + str(info.errorlist))
            print ('paralist = ' + str(info.paralist))
            if (self.retry and (errcode != 0)):
                print 'Current Cli is not vaild, retry askcli'
                stage = CHK_ModifyTelephoneNumberStage()
                runtime.manager.change_stage(stage)
                return 
            if (errcode == 0):
                setproxy(info.paralist[0][0], checknull=True)
                setCli(info.paralist[0][1])
                setSipkey(info.paralist[0][2])
                setSipDomain(info.paralist[0][3], checknull=True)

                def subscribe():
                    if runtime.vdciapp:
                        runtime.vdciapp.end_call()
                        runtime.vdciapp.kill_vdciapp()
                        runtime.vdciapp = None
                    runtime.manager.net_init()
                    setting.reset_screen_saver_timer()
                    stage = AliceNotifyStage(_('Service activated.\nWelcome to Alice Voice'), runtime.manager.back_stage('idle'), exit_to_idle=True)
                    runtime.manager.change_stage(stage)


                stage = AliceNotifyStage(((_('Phone Number assigned') + '\n') + _('Please wait...')))
                runtime.evas.idle_add(subscribe)
                import firstsms
                firstsms.reset_first_sms()
                setting.reset_screen_saver_timer()
                runtime.manager.change_stage(stage)
            elif (errcode == 1):
                stage = ModifyTelephoneNumberRetryStage(self.cli)
                runtime.manager.change_stage(stage)
            elif (errcode == 2):
                stage = AliceNotifyStage(((_('Phone Number incorrect') + '\n') + _('Please wait...')), exit_to_idle=True)
                runtime.manager.change_stage(stage)
            elif (errcode == 3):
                stage = AliceNotifyStage(_('Phone Number\nalready assigned'), exit_to_idle=True)
                runtime.manager.change_stage(stage)
            else:
                stage = AliceNotifyStage(_('Configuration error'), exit_to_idle=True)
                runtime.manager.change_stage(stage)
        except:
            print 'Exceptions occured'
            stage = AliceNotifyStage(_('Configuration error'), runtime.manager.back_stage('idle'), exit_to_idle=True)
            runtime.manager.change_stage(stage)



    def handle_key(self, key):
        print 'handle key'



    def destroy(self):
        print 'destroy'



class ModifyTelephoneNumberRetryStage(YesNoStage):
    __module__ = __name__
    icon = uiconfig.baloon_phone_setting_icon

    def __init__(self, cli):
        message = ((((_('Activating...') + '\n') + _('Please wait...')) + '\n') + _('Do not switch off the phone'))
        YesNoStage.__init__(self, message, self.yes_cb, self.no_cb, '', self.icon)
        self.ui.set_left('')
        self.ui.set_right(_('EXIT'))
        self.timer1 = utils.Timer(config.tisvc_timer_retry, self.do_retry)
        self.timer2 = utils.Timer(config.tisvc_timer_retry_end, self.do_expire)
        self.cli = cli



    def do_retry(self):
        print 'do_retry : by 5 min'
        setting.reset_screen_saver_timer()
        status.screensaver_activated = False
        try:
            info = aptcp.SetCLI(self.cli)
            errcode = int(info.errorlist[0][1])
            print ('errlist = ' + str(info.errorlist))
            print ('paralist = ' + str(info.paralist))
            if (errcode == 0):
                setproxy(info.paralist[0][0], checknull=True)
                setCli(info.paralist[0][1])
                setSipkey(info.paralist[0][2])
                setSipDomain(info.paralist[0][3], checknull=True)

                def subscribe():
                    os.system('sync')
                    stage = AliceNotifyStage(_('Service activated.\nWelcome to Alice Voice'), runtime.manager.back_stage('idle'), exit_to_idle=True)
                    runtime.manager.change_stage(stage)


                stage = AliceNotifyStage(((_('Phone Number assigned') + '\n') + _('Please wait...')), subscribe, exit_to_idle=True)
                runtime.manager.change_stage(stage)
            elif (errcode == 1):
                self.timer1 = utils.Timer(config.tisvc_timer_retry, self.do_retry)
            elif (errcode == 2):
                stage = AliceNotifyStage(((_('Phone Number incorrect') + '\n') + _('Please wait...')), runtime.manager.back_stage('idle'), exit_to_idle=True)
                runtime.manager.stack_stage(stage)
            elif (errcode == 3):
                stage = AliceNotifyStage(_('Phone Number already assigned'), runtime.manager.back_stage('idle'), exit_to_idle=True)
                runtime.manager.stack_stage(stage)
            else:
                stage = AliceNotifyStage(_('Configuration error'), runtime.manager.back_stage('idle'), exit_to_idle=True)
                runtime.manager.stack_stage(stage)
        except:
            print 'Exceptions occured'
            stage = AliceNotifyStage(_('Configuration error'), runtime.manager.back_stage('idle'), exit_to_idle=True)
            runtime.manager.stack_stage(stage)



    def do_expire(self):
        setting.reset_screen_saver_timer()
        status.screensaver_activated = False
        stage = ModifyTelephoneNumberFailStage
        runtime.manager.change_stage(stage)



    def destroy(self):
        self.timer1 = None
        self.timer2 = None
        YesNoStage.destroy(self)



    def yes_cb(self):
        pass


    def no_cb(self):
        self.timer1 = None
        self.timer2 = None
        runtime.manager.back_stage('idle')



class ModifyTelephoneNumberFailStage(YesNoStage):
    __module__ = __name__
    icon = uiconfig.baloon_phone_setting_icon

    def __init__(self):
        message = _('Failed.\nCall Help Desk')
        YesNoStage.__init__(self, message, self.yes_cb, self.no_cb, '', self.icon)
        self.ui.set_left('')
        self.ui.set_right(_('EXIT'))



    def yes_cb(self):
        pass


    def no_cb(self):
        runtime.manager.back_stage('idle')



class ViewTelephoneNumberStage(Stage):
    __module__ = __name__

    def __init__(self, index = None):
        if vdcisetting.CLI:
            import baseui
            self.ui = baseui.SmallWindowUI(_('MODIFY'), _('BACK'), _('ALICE'), _('Current number'))
            self.text = runtime.evas.text(font=uiconfig.entry_font)
            self.text.color = uiconfig.entry_color
            self.text.pos = uiconfig.entry_pos
            self.text.text = vdcisetting.CLI
            self.ui.add(self.text)
        else:
            import baseui
            self.ui = baseui.NotifyUI(_('No telephone number\nassigned'), uiconfig.baloon_alice_icon)
            self.ui.set_left(_('ASSIGN'))
            self.ui.set_right(_('BACK'))



    def activate_menu1(self):
        code = vdcisetting.CLI
        print 'telephone number =',
        print code
        stage = SelectNetworkPINCheckStage(2)
        runtime.manager.stack_stage(stage)



    def activate_menu2(self):
        runtime.manager.back_stage()



    def handle_key(self, key):
        if (key == config.Menu1):
            self.activate_menu1()
        elif ((key == config.Menu2) or (key == config.Red)):
            self.activate_menu2()
        return True



class SelectNetworkPINCheckStage(PINInputStage):
    __module__ = __name__

    def __init__(self, idx):
        PINInputStage.__init__(self, _('PIN:'), '', _('PIN'))
        self.idx = idx
        if (idx == 0):
            self.ui.title = _('SELECT NETWORK')
        elif (idx == 1):
            self.ui.title = _('MODIFY ACTIVATION CODE')
        elif (idx == 2):
            self.ui.title = _('MODIFY TELEPHONE NUMBER')



    def activate(self, pin):
        if (setting.pin == pin):
            if (self.idx == 0):
                stage = SelectNetworkStage
            elif (self.idx == 1):
                stage = ActivationCodeStage
            elif (self.idx == 2):
                stage = CHK_ModifyTelephoneNumberStage()
            runtime.manager.change_stage(stage)
        else:
            self.ui.pin = ''
            self.ui.update()
            stage = AliceNotifyStage(_('Wrong PIN!'))
            runtime.manager.stack_stage(stage)



class AliceStage(ListStage):
    __module__ = __name__
    title = _('ALICE')
    choice = (_('Select network'),
     _('Modify activation code'),
     _('Modify telephone number'))
    icon = uiconfig.lan_setting_icon

    def activate(self, index):
        stage = (SelectNetworkPINCheckStage,
         SelectNetworkPINCheckStage,
         ViewTelephoneNumberStage)[index]
        runtime.manager.stack_stage(stage(index))



    def handle_key(self, key):
        if (key == '*'):
            stage = AllNetwork
            runtime.manager.stack_stage(stage)
            runtime.evas.render_now()
            return 
        ListStage.handle_key(self, key)



class WifiScanNoListStage(YesNoStage):
    __module__ = __name__

    def __init__(self):
        YesNoStage.__init__(self, _('No network available'), self.yes_cb, self.no_cb, '', uiconfig.baloon_alice_icon)
        self.ui.set_left(_('RETRY'))
        self.ui.set_right(_('EXIT'))



    def yes_cb(self):
        stage = AllNetwork(poweron=True)
        runtime.manager.change_stage(stage)
        runtime.evas.render_now()
        return 



    def no_cb(self):
        runtime.manager.back_stage()



class WifiPressRegStage(YesNoStage):
    __module__ = __name__

    def __init__(self):
        YesNoStage.__init__(self, _('Reg button pressed?'), self.yes_cb, self.no_cb, '', uiconfig.baloon_alice_icon)



    def yes_cb(self):

        def wisecon_timeout():
            stage = ActivationCodeStage(poweron=True)
            runtime.manager.change_stage(stage)
            return 


        message = _('Please wait...')
        setting.reset_screen_saver_timer()
        stage = AliceNotifyStage(message, wisecon_timeout, exit_to_idle=True)
        runtime.manager.change_stage(stage)



    def no_cb(self):
        message = _('Press Registration button\n(Reg) on wi-fi module')
        stage = AliceNotifyStage(message, check_reg_pressed, exit_to_idle=True)
        runtime.manager.change_stage(stage)



class AliceNotifyStage(NotifyStage):
    __module__ = __name__

    def __init__(self, message, cb = None, exit_to_idle = False, noexit = False):
        icon = uiconfig.baloon_alice_icon
        self.exit_to_idle = exit_to_idle
        self.noexit = noexit
        NotifyStage.__init__(self, message, icon, cb)
        if self.noexit:
            self.ui.set_right('')
        else:
            self.ui.set_right(_('EXIT'))



    def handle_key(self, key):
        if ((not self.noexit) and (key == config.Menu2)):
            if self.exit_to_idle:
                runtime.manager.back_stage('idle')
            else:
                runtime.manager.back_stage()
            return 
        NotifyStage.handle_key(self, key)



_stages = (LastCallStage,
 LastCallsStage,
 TAMStage,
 AliceStage,
 Info412Stage,
 LogosStage,
 CallTransferStageForAlice,
 CallWaitingStage,
 CorrectTimeStage,
 WakeUpCallsStage,
 ChiarotelStage,
 UrgentCallStage,
 Service5Stage,
 AutoDisabilitazioneStage,
 MultiNumberStage,
 CIDStage,
 HideNumberStage)

def get_stage(index):
    if (profile.get_profile() == profile.PSTN):
        if (index == 6):
            return CallTransferStageForPSTN
    elif (profile.get_profile() == profile.LAN):
        if (index == 3):
            return ViewTelephoneNumberStage
    return _stages[index]



# local variables:
# tab-width: 4
